@@ -155,12 +155,7 @@ class HardwareViewSet(viewsets.ModelViewSet):
 
     def getChannels(self, hardware_id):
         channels = Hardware.objects.get(pk=str(hardware_id)).channel_set.all()
-        serialized_channels = []
-        for channel in channels:
-            temp_channel = Channel.objects.get(pk=channel.id)
-            serializer = ChannelSerializer(temp_channel)
-            serializer.is_valid()
-            serialized_channels.append(ChannelSerializer(temp_channel).data)
+        serialized_channels = ChannelSerializer(channels,many=True)
         # if request.accepted_renderer.format == 'html':
         print('get channels '+ str(hardware_id))
         print(str(serialized_channels))
